import { BlockhashWithExpiryBlockHeight, Cluster, Commitment, Context, MaybeRpcAccount, PublicKey, RpcAccount, RpcAccountExistsOptions, RpcAirdropOptions, RpcCallOptions, RpcConfirmTransactionOptions, RpcConfirmTransactionResult, RpcDataFilter, RpcGetAccountOptions, RpcGetAccountsOptions, RpcGetBalanceOptions, RpcGetLatestBlockhashOptions, RpcGetProgramAccountsOptions, RpcGetRentOptions, RpcGetTransactionOptions, RpcInterface, RpcSendTransactionOptions, SolAmount, Transaction, TransactionSignature, TransactionWithMeta } from '@lorisleiva/js-core';
import { AccountInfo as Web3JsAccountInfo, Connection as Web3JsConnection, ConnectionConfig as Web3JsConnectionConfig, GetProgramAccountsFilter as Web3JsGetProgramAccountsFilter, TransactionConfirmationStrategy as Web3JsTransactionConfirmationStrategy } from '@solana/web3.js';
export type Web3JsRpcOptions = Commitment | Web3JsConnectionConfig;
export declare class Web3JsRpc implements RpcInterface {
    protected readonly context: Pick<Context, 'programs' | 'transactions'>;
    readonly connection: Web3JsConnection;
    readonly cluster: Cluster;
    constructor(context: Pick<Context, 'programs' | 'transactions'>, endpoint: string, rpcOptions?: Web3JsRpcOptions);
    getEndpoint(): string;
    getCluster(): Cluster;
    getAccount(address: PublicKey, options?: RpcGetAccountOptions): Promise<MaybeRpcAccount>;
    getAccounts(addresses: PublicKey[], options?: RpcGetAccountsOptions): Promise<MaybeRpcAccount[]>;
    getProgramAccounts(programId: PublicKey, options?: RpcGetProgramAccountsOptions): Promise<RpcAccount[]>;
    getBalance(address: PublicKey, options?: RpcGetBalanceOptions): Promise<SolAmount>;
    getRent(bytes: number, options?: RpcGetRentOptions): Promise<SolAmount>;
    getLatestBlockhash(options?: RpcGetLatestBlockhashOptions): Promise<BlockhashWithExpiryBlockHeight>;
    getTransaction(signature: TransactionSignature, options?: RpcGetTransactionOptions): Promise<TransactionWithMeta | null>;
    accountExists(address: PublicKey, options?: RpcAccountExistsOptions): Promise<boolean>;
    airdrop(address: PublicKey, amount: SolAmount, options?: RpcAirdropOptions): Promise<void>;
    call<Result, Params extends any[]>(method: string, params?: [...Params], options?: RpcCallOptions): Promise<Result>;
    sendTransaction(transaction: Transaction, options?: RpcSendTransactionOptions): Promise<TransactionSignature>;
    confirmTransaction(signature: TransactionSignature, options: RpcConfirmTransactionOptions): Promise<RpcConfirmTransactionResult>;
    protected parseAccount(account: Web3JsAccountInfo<Uint8Array>, address: PublicKey): RpcAccount;
    protected parseMaybeAccount(account: Web3JsAccountInfo<Uint8Array> | null, address: PublicKey): MaybeRpcAccount;
    protected parseDataFilter(filter: RpcDataFilter): Web3JsGetProgramAccountsFilter;
    protected parseConfirmStrategy(signature: TransactionSignature, options: RpcConfirmTransactionOptions): Web3JsTransactionConfirmationStrategy;
}
